// 导入axios
import axios from 'axios'
// 使用element-plus ElMessage做消息提醒
import { ElMessage } from 'element-plus';
import Cookies from 'js-cookie'


//1. 创建新的axios实例，
const service = axios.create({
  baseURL: "/api",
  // 超时时间 单位是ms，这里设置了3s的超时时间
  timeout: 3 * 1000
})

// 请求拦截器
service.interceptors.request.use(config => {
  const TokenKey = 'vue_admin_template_token'
  const token = Cookies.get(TokenKey)
  if (token && typeof token !='undefined' && token != "") {
    (config.headers)['token'] = token
  }
  return config
}, error => {
  Promise.reject(error)
})

// 响应拦截器
service.interceptors.response.use(
  function (response) {
    if (response.data.code !== 200) {
      // 判断响应状态码
      if (response.data.code == 501) return Promise.reject(ElMessage.error("用户名有误"))
      else if (response.data.code == 503) return Promise.reject(ElMessage.error("密码有误"))
      else if (response.data.code == 504) return Promise.reject(ElMessage.error("登录已过期"))
      else if (response.data.code == 505) return Promise.reject(ElMessage.error("用户名占用"))
    } else {
      return response.data.data; /* 返回成功响应数据中的data属性数据 */
    }
    return response;
  },
  function (error) {
    if(error.response.status == 500) return Promise.reject(ElMessage.error("服务器报错"))
  });


//4.导入文件
export default service